# rmsy-utls

[![status](http://www.repostatus.org/badges/latest/concept.svg)](http://www.repostatus.org/#concept)
[![ci](https://github.com/ramsey-devs/rmsy-utls/actions/workflows/ci.yaml/badge.svg)](https://github.com/ramsey-devs/rmsy-utls/actions/workflows/ci.yaml)

> Utility functions for Ramsey

## About

Contains some utility functions for using Ramsey and other JAX-based packages.

## Installation

To install the latest GitHub <RELEASE>, just call the following on the
command line:

```bash
pip install git+https://github.com/ramsey-devs/rmsy-utls@<RELEASE>
```

## Author

Simon Dirmeier <a href="mailto:sfyrbnd @ pm me">sfyrbnd @ pm me</a>
